@@ -10,6 +10,8 @@
 use strict;
 use warnings;
 
+use Mail::DKIM::PrivateKey;
+
 package Mail::DKIM::Algorithm::rsa_sha256;
 use base "Mail::DKIM::Algorithm::Base";
 use Carp;
@@ -22,7 +24,14 @@ sub init_digests
 
 	# initialize a SHA-256 Digest
 	$self->{header_digest} = new Digest::SHA(256);
-	$self->{body_digest} = new Digest::SHA(256);
+	if ($self->{draft_version} eq "01")
+	{
+		$self->{body_digest} = new Digest::SHA(256);
+	}
+	else
+	{
+		$self->{body_digest} = $self->{header_digest};
+	}
 }
 
 sub sign
@@ -40,10 +49,8 @@ sub sign
 sub verify
 {
 	my $self = shift;
-	croak "wrong number of arguments" unless (@_ == 0);
-
-	my $base64 = $self->signature->data;
-	my $public_key = $self->signature->get_public_key;
+	croak "wrong number of arguments" unless (@_ == 2);
+	my ($base64, $public_key) = @_;
 
 	my $digest = $self->{header_digest}->digest;
 	my $sig = decode_base64($base64);
@@ -51,9 +58,26 @@ sub verify
 	return $self->check_body_hash;
 }
 
-sub wants_pre_signature_headers
-{
-	return 1;
-}
-
 1;
+
+__END__
+
+=head1 NAME
+
+Mail::DKIM::Algorithm::rsa_sha256 - implements the rsa-sha256 signing algorithm for DKIM
+
+=head1 CONSTRUCTOR
+
+=head2 new() - create an object for the DKIM signing algorithm "rsa-sha256"
+
+  my $algorithm = new Mail::DKIM::Algorithm::rsa_sha256(
+                      Signature => $dkim_signature
+                  );
+
+=head1 METHODS
+
+See Mail::DKIM::Algorithm::Base for the full list of methods supported
+by this algorithm class.
+
+=cut
+
